@@ -21,7 +21,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA.
  */
 
@@ -69,61 +69,61 @@ GType e_destination_get_type (void);
 
 
 EDestination  *e_destination_new                (void);
-EDestination  *e_destination_copy               (const EDestination *);
+EDestination  *e_destination_copy               (const EDestination *dest);
 
-gboolean       e_destination_empty              (const EDestination *);
+gboolean       e_destination_empty              (const EDestination *dest);
 gboolean       e_destination_equal              (const EDestination *a, const EDestination *b);
 
 /* for use with EDestinations that wrap a particular contact */
-void           e_destination_set_contact        (EDestination *, EContact *contact, int email_num);
+void           e_destination_set_contact        (EDestination *dest, EContact *contact, int email_num);
 void           e_destination_set_contact_uid    (EDestination *dest, const char *uid, gint email_num);
-void           e_destination_set_book           (EDestination *, EBook *book);
-EContact      *e_destination_get_contact        (const EDestination *);
-const char    *e_destination_get_source_uid     (const EDestination *);
-const char    *e_destination_get_contact_uid    (const EDestination *);
-int            e_destination_get_email_num      (const EDestination *);
+void           e_destination_set_book           (EDestination *dest, EBook *book);
+EContact      *e_destination_get_contact        (const EDestination *dest);
+const char    *e_destination_get_source_uid     (const EDestination *dest);
+const char    *e_destination_get_contact_uid    (const EDestination *dest);
+int            e_destination_get_email_num      (const EDestination *dest);
 
 /* for use with EDestinations built up from strings (not corresponding to contacts in a user's address books) */
-void           e_destination_set_name           (EDestination *, const char *name);
-void           e_destination_set_email          (EDestination *, const char *email);
-const char    *e_destination_get_name           (const EDestination *);  /* "Jane Smith" */
-const char    *e_destination_get_email          (const EDestination *);  /* "jane@assbarn.com" */
-const char    *e_destination_get_address        (const EDestination *);  /* "Jane Smith <jane@assbarn.com>" (or a comma-sep set of such for a list) */
+void           e_destination_set_name           (EDestination *dest, const char *name);
+void           e_destination_set_email          (EDestination *dest, const char *email);
+const char    *e_destination_get_name           (const EDestination *dest);  /* "Jane Smith" */
+const char    *e_destination_get_email          (const EDestination *dest);  /* "jane@assbarn.com" */
+const char    *e_destination_get_address        (const EDestination *dest);  /* "Jane Smith <jane@assbarn.com>" (or a comma-sep set of such for a list) */
 
-gboolean       e_destination_is_evolution_list   (const EDestination *);
-gboolean       e_destination_list_show_addresses (const EDestination *);
-const GList   *e_destination_list_get_dests      (const EDestination *);
+gboolean       e_destination_is_evolution_list   (const EDestination *dest);
+gboolean       e_destination_list_show_addresses (const EDestination *dest);
+const GList   *e_destination_list_get_dests      (const EDestination *dest);
 gboolean       e_destination_is_ignored  	 (const EDestination *dest);
-void           e_destination_set_ignored 	 (EDestination *view, gboolean ignored);
+void           e_destination_set_ignored 	 (EDestination *dest, gboolean ignored);
 
 /* If true, they want HTML mail. */
 void           e_destination_set_html_mail_pref (EDestination *dest, gboolean flag);
-gboolean       e_destination_get_html_mail_pref (const EDestination *);
+gboolean       e_destination_get_html_mail_pref (const EDestination *dest);
 
 /* used by the evolution composer to manage automatic recipients
 
    XXX should probably be implemented using a more neutral/extensible
    approach instead of a hardcoded evolution-only flag. */
-gboolean       e_destination_is_auto_recipient  (const EDestination *);
-void           e_destination_set_auto_recipient (EDestination *, gboolean value);
+gboolean       e_destination_is_auto_recipient  (const EDestination *dest);
+void           e_destination_set_auto_recipient (EDestination *dest, gboolean value);
 
 /* parse out an EDestination (name/email, not contact) from a free form string. */
-void           e_destination_set_raw            (EDestination *, const char *free_form_string);
+void           e_destination_set_raw            (EDestination *dest, const char *raw);
 
 /* generate a plain-text representation of an EDestination* or EDestination** */
-const char    *e_destination_get_textrep        (const EDestination *, gboolean include_email);  /* "Jane Smith" or "jane@assbarn.com" */
-char          *e_destination_get_textrepv       (EDestination **);
+const char    *e_destination_get_textrep        (const EDestination *dest, gboolean include_email);  /* "Jane Smith" or "jane@assbarn.com" */
+char          *e_destination_get_textrepv       (EDestination **destv);
 
 /* XML export/import routines. */
-char          *e_destination_export             (const EDestination *);
-char          *e_destination_exportv            (EDestination **);
+char          *e_destination_export             (const EDestination *dest);
+char          *e_destination_exportv            (EDestination **destv);
 EDestination  *e_destination_import             (const char *str);
 EDestination **e_destination_importv            (const char *str);
 
 /* EVCard "export" routines */
 void          e_destination_export_to_vcard_attribute   (EDestination *dest, EVCardAttribute *attr);
 
-void           e_destination_freev              (EDestination **);
+void           e_destination_freev              (EDestination **destv);
 
 #endif /* __E_DESTINATION_H__ */
 
