@@ -1,6 +1,3 @@
-
-#include <libgnome/gnome-init.h>
-#include <bonobo/bonobo-main.h>
 #include <stdlib.h>
 #include <string.h>
 #include <libebook/e-book.h>
@@ -12,10 +9,7 @@ main (int argc, char **argv)
 {
 	EContact *contact;
 
-	gnome_program_init("test-string", "0.0", LIBGNOME_MODULE, argc, argv, NULL);
-
-	if (bonobo_init (&argc, argv) == FALSE)
-		g_error ("Could not initialize Bonobo");
+	g_type_init ();
 
 	contact = e_contact_new ();
 
