@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -345,7 +345,8 @@ get_deltas (gpointer handle)
 
 	attempts = e_cal_backend_cache_get_key_value (cache, key);
 
-	g_static_mutex_lock (&connecting);
+	if (!g_static_mutex_trylock (&connecting))
+			return TRUE;
 
 	serv_time = e_cal_backend_cache_get_server_utc_time (cache);
 	if (serv_time) {
@@ -801,9 +802,10 @@ set_container_id_with_count (ECalBackendGroupwise *cbgw)
 	res =  GNOME_Evolution_Calendar_ObjectNotFound;
 	for (l = container_list; l != NULL; l = l->next) {
 		EGwContainer *container = E_GW_CONTAINER (l->data);
-		const char *name = e_gw_container_get_name (container);
 		
-		if (name && strcmp (name, "Calendar") == 0) {
+		if (e_gw_container_get_is_system_folder (container) && 
+				e_gw_container_get_container_type (container) == E_GW_CONTAINER_TYPE_CALENDAR) {
+
 			priv->container_id = g_strdup (e_gw_container_get_id (container));
 			priv->total_count = e_gw_container_get_total_count (container);
 			res = GNOME_Evolution_Calendar_Success;
