@@ -967,6 +967,18 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 		
 		/* size */
 		size = strtoul ((const char *) inptr, &p, 10);
+		/* check if the size wasn't negative */
+		if (p) {
+			while (inptr < p && *inptr != '-')
+				inptr++;
+
+			if (inptr < p)
+				size = 0;
+		}
+
+		if (size == 0)
+			goto exception;
+
 		inptr = (const unsigned char *) p;
 		
 		if (camel_content_type_is (ctype, "message", "rfc822")) {
@@ -977,7 +989,7 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 			/* envelope */
 			imap_skip_list (&inptr);
 			
-			if (*inptr++ != ' ')
+			if (!inptr || *inptr++ != ' ')
 				goto exception;
 			
 			/* body */
@@ -985,14 +997,14 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 				goto exception;
 			child->parent = ci;
 			
-			if (*inptr++ != ' ')
+			if (!inptr || *inptr++ != ' ')
 				goto exception;
 			
 			/* lines */
 			strtoul ((const char *) inptr, &p, 10);
 			inptr = (const unsigned char *) p;
 		} else if (camel_content_type_is (ctype, "text", "*")) {
-			if (*inptr++ != ' ')
+			if (!inptr || *inptr++ != ' ')
 				goto exception;
 			
 			/* lines */
@@ -1002,7 +1014,7 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 			/* body_type_basic */
 		}
 		
-		if (*inptr++ != ')')
+		if (!inptr || *inptr++ != ')')
 			goto exception;
 		
 		ci->type = ctype;
